#
# spec file for package sssd
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#



Name:           sssd
Version:        1.5.11
Release:        2
Group:          System/Daemons
Summary:        System Security Services Daemon
License:        GPL-3.0+ and LGPL-3.0+
Url:            https://fedorahosted.org/sssd/
Source0:        %{name}-%{version}.tar.bz2
Source1:        baselibs.conf
Patch1:         0001-sss_client-avoid-leaking-file-descriptors.patch
Patch2:         0002-Request-password-control-unconditionally-during-bind.patch
Patch3:         0003-Allow-LDAP-to-decide-when-an-expiration-warning-is-w.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if %suse_version > 1140
%{?systemd_requires}
%endif

%define servicename sssd
%define sssdstatedir %{_localstatedir}/lib/sss
%define dbpath %{sssdstatedir}/db
%define pipepath %{sssdstatedir}/pipes
%define pubconfpath %{sssdstatedir}/pubconf

# SLES11 doesn't know the python_* macros
%if %suse_version <= 1110
%define python_sitelib %py_sitedir
%define python_sitearch %py_sitedir
%endif

### Build Dependencies ###
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  m4
BuildRequires:  popt-devel
BuildRequires:  libtalloc-devel
BuildRequires:  libtevent-devel
BuildRequires:  libtdb-devel
BuildRequires:  libldb-devel
BuildRequires:  libxslt
BuildRequires:  libxml2
BuildRequires:  libcares-devel
BuildRequires:  dbus-1-devel
BuildRequires:  openldap2-devel
BuildRequires:  pam-devel
BuildRequires:  pkg-config
BuildRequires:  pcre-devel
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  krb5-devel
BuildRequires:  python-devel
BuildRequires:  bind-utils
BuildRequires:  nscd
BuildRequires:  libpath_utils-devel
BuildRequires:  libdhash-devel
BuildRequires:  libini_config-devel
BuildRequires:  libcollection-devel
BuildRequires:  libref_array-devel
%if %suse_version > 1140
BuildRequires:  systemd
BuildRequires:  libnl-1_1-devel
%else
BuildRequires:  libnl-devel
%endif

%description
Provides a set of daemons to manage access to remote directories and
authentication mechanisms. It provides an NSS and PAM interface toward
the system and a pluggable backend system to connect to multiple different
account sources. It is also the basis to provide client auditing and policy
services for projects like FreeIPA.

%package ipa-provider
License:        GPL-3.0+ and LGPL-3.0+
Summary:        FreeIPA provider plugin for sssd
Group:          System/Daemons
Requires:       sssd = %{version}

%description ipa-provider
This package provide the FreeIPA provider plugin for the System Security
Services Daemon (sssd).

%package tools
License:        GPL-3.0+ and LGPL-3.0+
Summary:        Commandline tools for sssd
Group:          System/Management
Requires:       sssd = %{version}

%description tools
The packages contains commandline tools for managing users and groups using
the "local" id provider of the System Security Services Daemon (sssd).

%package -n python-sssd-config
License:        GPL-3.0+ and LGPL-3.0+
Summary:        Python API for configuring sssd
Group:          Development/Libraries/Python
%{py_requires}

%description -n python-sssd-config
Provide python module to access and manage configuration of the System 
Security Services Daemon (sssd).

%prep
%setup -q
%patch -P 1 -P 2 -P 3 -p1

%build
autoreconf
export LDB_LIBS="-lldb"
export LDB_CFLAGS="-I/usr/include"

# help configure find nscd
export PATH=$PATH:/usr/sbin/

%configure \
    --with-db-path=%{dbpath} \
    --with-pipe-path=%{pipepath} \
    --with-pubconf-path=%{pubconfpath} \
    --with-init-dir=%{_initrddir} \
    --enable-nsslibdir=/%{_lib} \
    --enable-pammoddir=/%{_lib}/security \
    --enable-crypto=yes \
    --with-ldb-lib-dir=%{_libdir}/ldb \
    --with-selinux=no \
    --with-os=suse \
    --with-semanage=no
make %{?_smp_mflags}

%install
make install DESTDIR=$RPM_BUILD_ROOT

# Copy default sssd.conf file
install -d $RPM_BUILD_ROOT/%{_sysconfdir}/sssd
install -m600 src/examples/sssd.conf $RPM_BUILD_ROOT%{_sysconfdir}/sssd/sssd.conf
install src/sysv/SUSE/sssd $RPM_BUILD_ROOT%{_sysconfdir}/init.d/sssd
%if %suse_version > 1140
install -d $RPM_BUILD_ROOT/%{_unitdir}
install src/sysv/systemd/sssd.service $RPM_BUILD_ROOT/%{_unitdir}/sssd.service
%endif
ln -sf ../../etc/init.d/sssd $RPM_BUILD_ROOT/usr/sbin/rcsssd

# Remove .la files created by libtool
find "%buildroot" -type f -name "*.la" -delete;

%if %suse_version <= 1110
# remove some unsupported languages, sssd does not contain
# translations for these anyway
rm -rf \
    $RPM_BUILD_ROOT/usr/share/locale/fa_IR \
    $RPM_BUILD_ROOT/usr/share/locale/ja_JP \
    $RPM_BUILD_ROOT/usr/share/locale/lt_LT \
    $RPM_BUILD_ROOT/usr/share/locale/ta_IN \
    $RPM_BUILD_ROOT/usr/share/locale/vi_VN
%endif

%find_lang %{name} --all-name

%clean
rm -rf $RPM_BUILD_ROOT

%if %suse_version > 1140

%pre
%service_add_pre sssd.service
%endif

%post
/sbin/ldconfig
%if %suse_version > 1140
%service_add_post sssd.service
%endif

%preun
%stop_on_removal sssd
%if %suse_version > 1140
%service_del_preun sssd.service
%endif

%postun
/sbin/ldconfig
%restart_on_update sssd
%insserv_cleanup
%if %suse_version > 1140
%service_del_postun sssd.service
%endif

%files -f sssd.lang
%defattr(-,root,root,-)
%doc COPYING
%{_initrddir}/%{name}
%if %suse_version > 1140
%{_unitdir}/sssd.service
%endif
%{_sbindir}/sssd
%{_sbindir}/rcsssd
%dir %{_libdir}/%{name}
%dir %{_libexecdir}/%{name}
%{_libexecdir}/%{name}/sss*
%{_libexecdir}/%{name}/*_child
%{_libdir}/%{name}/libsss_krb5*
%{_libdir}/%{name}/libsss_ldap*
%{_libdir}/%{name}/libsss_proxy*
%{_libdir}/%{name}/libsss_simple*
%{_libdir}/ldb/memberof.so
%{_libdir}/krb5/plugins/libkrb5/*
%dir %{sssdstatedir}
%attr(700,root,root) %dir %{dbpath}
%attr(755,root,root) %dir %{pipepath}
%attr(700,root,root) %dir %{pipepath}/private
%attr(755,root,root) %dir %{pubconfpath}
%attr(750,root,root) %dir %{_var}/log/%{name}
%dir %{_sysconfdir}/sssd
%config(noreplace) %{_sysconfdir}/sssd/sssd.conf
%config %{_sysconfdir}/sssd/sssd.api.conf
%attr(700,root,root) %dir %{_sysconfdir}/sssd/sssd.api.d
%config %{_sysconfdir}/sssd/sssd.api.d/sssd-krb5.conf
%config %{_sysconfdir}/sssd/sssd.api.d/sssd-ldap.conf
%config %{_sysconfdir}/sssd/sssd.api.d/sssd-local.conf
%config %{_sysconfdir}/sssd/sssd.api.d/sssd-proxy.conf
%config %{_sysconfdir}/sssd/sssd.api.d/sssd-simple.conf
/%{_lib}/libnss_sss.so.2
/%{_lib}/security/pam_sss.so
%{_mandir}/man5/sssd-krb5.*
%{_mandir}/man5/sssd-ldap.*
%{_mandir}/man5/sssd-simple.*
%{_mandir}/man5/sssd.conf.*

%files tools
%defattr(-,root,root,-)
%dir %{_mandir}/cs
%dir %{_mandir}/cs/man8
%dir %{_mandir}/uk
%dir %{_mandir}/uk/man8
%dir %{_mandir}/es
%dir %{_mandir}/es/man8
%dir %{_mandir}/nl
%dir %{_mandir}/nl/man8
%{_mandir}/man8/*
%{_mandir}/cs/man8/*
%{_mandir}/uk/man8/*
%{_mandir}/es/man8/*
%{_mandir}/nl/man8/*
%{_sbindir}/sss_useradd
%{_sbindir}/sss_userdel
%{_sbindir}/sss_usermod
%{_sbindir}/sss_groupadd
%{_sbindir}/sss_groupdel
%{_sbindir}/sss_groupmod
%{_sbindir}/sss_groupshow
%attr(0755,root,root) %{_sbindir}/sss_obfuscate

%files ipa-provider
%defattr(-,root,root,-)
%config %{_sysconfdir}/sssd/sssd.api.d/sssd-ipa.conf
%{_libdir}/sssd/libsss_ipa*
%{_mandir}/man5/sssd-ipa.*

%files -n python-sssd-config
%defattr(-,root,root,-)
%{python_sitearch}/pysss.so
%{python_sitelib}/*.py*
%{python_sitelib}/*.egg-info

%changelog
